# Shox
Shox combines the all powerful shodan.io port-scanning and OSINT-gathering capabilities with ExploitDB's onhand downloadable Exploits.
Hence the name.

## Dependencies and their Purpose 

Selenium -> scraping
BeautifulSoup -> html parsing
Click -> CLI
requests -> requests
